@@ -386,14 +386,14 @@ from ae.paths import (
     add_common_storage_paths, copy_file, copy_tree, normalize, path_folders, path_name, placeholder_path,
     Collector, FilesRegister, placeholder_key)
 from ae.updater import MOVES_SRC_FOLDER_NAME, check_all                                                 # type: ignore
-from ae.inspector import stack_var                                                                      # type: ignore
+from ae.inspector import stack_var, try_call                                                            # type: ignore
 from ae.i18n import (                                                                                   # type: ignore
     default_language, get_f_string, get_text, load_language_texts, register_translations_path)
 from ae.core import DEBUG_LEVELS, registered_app_names                                                  # type: ignore
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.3.85'
+__version__ = '0.3.86'
 
 
 APP_STATE_SECTION_NAME = 'aeAppState'           #: config section name to store app state
@@ -1068,13 +1068,22 @@ class MainAppBase(ConsoleApp, ABC):
         """ load application state from the config files to prepare app.run_app """
         app_states = {}
         for key in self.app_state_keys():
-            app_states[key] = self.get_var(key, section=APP_STATE_SECTION_NAME)
-            if self.debug:
-                pre = f"   #  app state '{key}' "
-                if not hasattr(self, key):
-                    self.dpo(f"{pre}is not declared as MainAppBase attribute")
-                elif not isinstance(app_states[key], type(getattr(self, key))):
-                    self.dpo(f"{pre}type mismatch: attr={type(getattr(self, key))} config-var={type(app_states[key])}")
+            pre = f"   #  app state '{key}' "
+            if not hasattr(self, key):
+                self.dpo(f"{pre}ignored because it is not declared as MainAppBase attribute")
+                continue
+
+            type_class = type(getattr(self, key))
+            value = self.get_var(key, section=APP_STATE_SECTION_NAME)
+            if not isinstance(value, type_class):   # type mismatch - try to autocorrect
+                self.dpo(f"{pre}type mismatch: attr={type_class} config-var={type(value)}")
+                corr_val = try_call(type_class, value, ignored_exceptions=(Exception, TypeError, ValueError))
+                if corr_val is UNSET:
+                    self.po(f"{pre}type mismatch in '{value}' could not be corrected to {type_class}")
+                else:
+                    value = corr_val
+
+            app_states[key] = value
 
         self.setup_app_states(app_states)
 
